@@ -44,37 +44,37 @@ def function_help(func):
     params.append("")
 
     if isinstance(func, PipelineSeed):
-        return """results, summary = dsk.pipeline.auto({{'seed': '{}', 'params':{{{}}}}})""".format(
+        return """results, summary = client.pipeline.auto({{'seed': '{}', 'params':{{{}}}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Feature Generator":
-        return """dsk.pipeline.add_feature_generator([{{'name':'{}', 'params':{{{}}}}}])""".format(
+        return """client.pipeline.add_feature_generator([{{'name':'{}', 'params':{{{}}}}}])""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Feature Selector":
-        return """dsk.pipeline.add_feature_selector([{{'name':'{}', 'params':{{{}}}}}], params={{'number_of_features':(int)}})""".format(
+        return """client.pipeline.add_feature_selector([{{'name':'{}', 'params':{{{}}}}}], params={{'number_of_features':(int)}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type in ["Segmenter", "Transform", "Sampler"]:
-        return """dsk.pipeline.add_transform("{}", params={{{}}})""".format(
+        return """client.pipeline.add_transform("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Training Algorithm":
-        return """dsk.pipeline.set_training_algorithm("{}", params={{{}}})""".format(
+        return """client.pipeline.set_training_algorithm("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Validation Method":
-        return """dsk.pipeline.set_validation_method("{}", params={{{}}})""".format(
+        return """client.pipeline.set_validation_method("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Classifier":
-        return """dsk.pipeline.set_classifier("{}", params={{{}}})""".format(
+        return """client.pipeline.set_classifier("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
@@ -219,22 +219,22 @@ def pipeline_function_help(
         )
 
     if func.type in ["Segmenter", "Transform", "Sampler"]:
-        return """dsk.pipeline.add_transform("{}", params={{{}}})""".format(
+        return """client.pipeline.add_transform("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Training Algorithm":
-        return """dsk.pipeline.set_training_algorithm("{}", params={{{}}})""".format(
+        return """client.pipeline.set_training_algorithm("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Validation Method":
-        return """dsk.pipeline.set_validation_method("{}", params={{{}}})""".format(
+        return """client.pipeline.set_validation_method("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
     if func.type == "Classifier":
-        return """dsk.pipeline.set_classifier("{}", params={{{}}})""".format(
+        return """client.pipeline.set_classifier("{}", params={{{}}})""".format(
             func.name, param_tabs.join(params)
         )
 
@@ -242,7 +242,7 @@ def pipeline_function_help(
 
 
 def build_pipeline(function_list, steps):
-    pipeline_steps = ["dsk.pipeline.reset()"]
+    pipeline_steps = ["client.pipeline.reset()"]
 
     for step in steps:
         if step.get("type") == "generatorset":
@@ -252,7 +252,7 @@ def build_pipeline(function_list, steps):
                     pipeline_function_help(function_list, generator)
                 )
             pipeline_steps.append(
-                """dsk.pipeline.add_feature_generator([{}])""".format(
+                """client.pipeline.add_feature_generator([{}])""".format(
                     ",\n{}".format(" " * 40).join(feature_generators)
                 )
             )
@@ -264,7 +264,7 @@ def build_pipeline(function_list, steps):
                     pipeline_function_help(function_list, selector)
                 )
             pipeline_steps.append(
-                "dsk.pipeline.add_feature_selector([{}])"
+                "client.pipeline.add_feature_selector([{}])"
                 "".format("\n{}".format(" " * 40).join(feature_selectors))
             )
 
@@ -276,14 +276,14 @@ def build_pipeline(function_list, steps):
                     )
 
             pipeline_steps.append(
-                "dsk.pipeline.set_tvo({{'validation_seed':{}}})".format(
+                "client.pipeline.set_tvo({{'validation_seed':{}}})".format(
                     step.get("validation_seed", 0)
                 )
             )
 
         elif step.get("type", None) == "featurefile":
             pipeline_steps.append(
-                """dsk.pipeline.set_input_data("{}", data_columns={}, \n{}group_columns={},\n{}label_column="{}")""".format(
+                """client.pipeline.set_input_data("{}", data_columns={}, \n{}group_columns={},\n{}label_column="{}")""".format(
                     step.get("name", None),
                     step.get("data_columns", None),
                     " " * 40,
@@ -295,7 +295,7 @@ def build_pipeline(function_list, steps):
 
         elif step.get("type", None) == "query":
             pipeline_steps.append(
-                """dsk.pipeline.set_input_query("{query_name}", use_session_preprocessor={use_session_preprocessor})""".format(
+                """client.pipeline.set_input_query("{query_name}", use_session_preprocessor={use_session_preprocessor})""".format(
                     query_name=step.get("name", None),
                     use_session_preprocessor=step.get("use_session_preprocessor", True),
                 )
