@@ -158,7 +158,7 @@ class Connection(object):
 
         if not self.session.token:
             try:
-                self.session.fetch_token(
+                r = self.session.fetch_token(
                     token_url=self.token_url,
                     username=self.username,
                     password=password,
