@@ -6,6 +6,7 @@ from sensiml.datamanager.featurefiles import FeatureFiles
 from sensiml.datamanager.projects import Projects
 from sensiml.datamanager.segmenter import SegmenterSet
 from sensiml.datamanager.capture_configurations import CaptureConfigurations
+from sensiml.datamanager.team import Team
 
 
 __all__ = [
@@ -17,4 +18,5 @@ __all__ = [
     "PlatformDescriptions",
     "ClientPlatformDescriptions",
     "CaptureConfigurations",
+    "Team",
 ]
