@@ -155,7 +155,7 @@ class Capture(object):
         try_ = 0
         url = "project/{0}/capture/{1}/".format(self._project.uuid, self.uuid)
 
-        while retries is 0 or try_ <= retries:
+        while retries == 0 or try_ <= retries:
             try_ += 1
             response = self._connection.request("get", url)
             response_data, err = utility.check_server_response(response)
