@@ -694,7 +694,7 @@ class KnowledgePack(VisualizeMixin):
         if platform is not None and type(platform) is ClientPlatformDescription:
             kwargs["config"] = {"target_platform": platform.id}
         elif platform is not None and type(platform) is not ClientPlatformDescription:
-            err_msg = "Platform not properly specified. Specify via dsk.platforms()"
+            err_msg = "Platform not properly specified. Specify via client.platforms()"
             if renderer:
                 renderer.render(err_msg)
             return err_msg, False
@@ -802,7 +802,7 @@ class KnowledgePack(VisualizeMixin):
         if platform is not None and type(platform) is PlatformDescription:
             kwargs["config"] = {"target_platform": platform.id}
         elif platform is not None and type(platform) is not PlatformDescription:
-            err_msg = "Platform not properly specified. Specify via dsk.platforms()"
+            err_msg = "Platform not properly specified. Specify via client.platforms()"
             if renderer:
                 renderer.render(err_msg)
             return err_msg, False
