@@ -45,6 +45,9 @@ class QueryColumns(object):
     def __str__(self):
         return json.dumps(self._columns)
 
+    def __iter__(self):
+        return iter(self._columns)
+
 
 class Query(object):
     """Base class for a query.
