@@ -1,16 +1,16 @@
-import itertools
 import copy
+import itertools
 import json
-import time
 import logging
+import time
+
+import numpy as np
+from pandas import DataFrame
 from requests.exceptions import HTTPError
 from six import string_types
-import numpy as np
 
-from pandas import DataFrame
-
-from sensiml.base.exceptions import DuplicateValueError
 import sensiml.base.utility as utility
+from sensiml.base.exceptions import DuplicateValueError
 from sensiml.base.snippets import generate_pipeline
 
 try:
@@ -390,24 +390,6 @@ class Pipeline(object):
         given below.
 
         Args:
-            seed (str) : Pipeline templates that focus on different feature libraries. Options and definitions are given below.
-
-                - **Basic Features**: Generates a set of all-purpose, high-performance features using statistical, energy, and rate of change feature
-                  generators. The seed then performs feature selection and model generation algorithms with a genetic algorithm to optimize
-                  pipeline parameters.
-
-                - **Advanced Features**: Generates a comprehensive set of features using statistical, energy, amplitude, shape, time, and rate of
-                  change feature generators. The seed then performs feature selection and model generation algorithms with a genetic algorithm
-                  to optimize pipeline parameters.
-
-                - **Histogram_Features**: Generates a set of histogram features and then performs feature selection and model generation algorithms
-                  with a genetic algorithm to optimize pipeline parameters.
-
-                - **Downsampled_Features**: Generates a set of downsampled features and then performs feature selection and model generation algorithms
-                  with a genetic algorithm to optimize pipeline parameters.
-
-                - **Custom**: Uses the user-defined pipeline to extract features and then searches for optimal parameters for the feature selection step,
-                  if defined, and the model generation step (required) using a genetic algorithm.
 
             params (dict) : Parameters of the genetic algorithm to optimize the pipelines. Definition and options of the parameters are given below.
                 - search_steps, (list, ['selectorset', 'tvo']): it is used to define which libraries in the pipelines will be optimized.
@@ -427,13 +409,6 @@ class Pipeline(object):
                 - allow_unknown, (bool, False): Allows creating unknown prediction results for the vectors. A vector is classified as an unknown if it
 
                     cannot be recognized by any neurons.
-                - demean_segments, (bool, False): Removes the mean from the input data before extracting features.
-
-                - validation_method, (Stratified Shuffle Split): Validation method that will be used in optimization
-
-                - balance_data, (bool, False): Use Undersampling of the Majority classes to balance the data prior to Model Building
-
-                - outlier_filter, (bool, False): Filter outliers using Isolation Forest Filter with a filter percent of 5.
 
                 - fitness (dict): Fitness parameters are combination of statistical and cost variables. It is used to evaluate the performance of
                   the models found by the algorithm. The user will define the coefficient scores for the parameters to define the priority of
@@ -475,8 +450,7 @@ class Pipeline(object):
 
                 client.pipeline.add_transform("Windowing", params={"window_size": 100, "delta": 100 })
 
-                results, summary = client.pipeline.auto({'seed': 'Basic Features',
-                                                    'params':{"search_steps": ['selectorset', 'tvo'],
+                results, summary = client.pipeline.auto({ 'params':{"search_steps": ['selectorset', 'tvo'],
                                                                 "population_size": 10,
                                                                 "iterations": 1,
                                                                 "mutation_rate": 0.1,
@@ -485,9 +459,7 @@ class Pipeline(object):
                                                                 "number_of_models_to_return": 5,
                                                                 "run_parallel": True,
                                                                 "allow_unknown": False,
-                                                                "validation_method": "'Stratified Shuffle Split'",
-                                                                "fitness": {'neurons': 0.5,
-                                                                            'accuracy': 1.0,
+                                                                "fitness": {'accuracy': 1.0,
                                                                             'f1_score': 0.0,
                                                                             'features': 0.3,
                                                                             'precision': 0.0,
@@ -1328,7 +1300,25 @@ class Pipeline(object):
         feature_columns=None,
         class_map=None,
         dtype=np.int32,
+        int8_input_type=True,
+        shape=None,
     ):
+        """Converts a SensiML feature vector Dataframe into a train, test, validate set of Numpy arrays to use in training a tensorflow model
+
+        Args:
+            feature_vectors (DataFrame): DataFrame of feature vectors returned from SensiML Pipeline
+            validate (float, optional): percentage of data to use in validation set. Defaults to 0.1.
+            test (float, optional): percentage of data to use in test set. Defaults to 0.1.
+            label (str, optional): the label column for the feature vectors. Defaults to None.
+            feature_columns (list, optional): the coluns of the feature vector DataFrame containing features. Defaults to None.
+            class_map (dict, optional): a class map describing the mapping of labels to int values. Defaults to None.
+            dtype (_type_, optional): the dtype of the tensorflow object to create. Defaults to np.int32.
+            int8_input_type (bool, optional): Scales the SensiML Features to int8 from uint8. Defaults to True.
+            shape (tuple, optional): Reshape the dataframe before loading it into the numpy array. Defaults to None.
+
+        Returns:
+            A tuple containing numpy arrays for traning a TensorFlow model along with the class map x_train, x_test, x_validate, y_train, y_test, y_validate, class_map
+        """
         if label is None:
             label = self._label_column
 
@@ -1347,15 +1337,20 @@ class Pipeline(object):
             ]
 
         resample = feature_vectors.sample(frac=1, axis=0).reset_index(drop=True)
-        resample_features = resample[feature_columns]
+
+        if int8_input_type:
+            resample_features = resample[feature_columns] - 127
+        else:
+            resample_features = resample[feature_columns]
 
         y_values_encoded = get_one_hot(resample["__CAT_LABEL__"].values, num_classes)
 
         y_values_encoded = y_values_encoded.reshape(resample.shape[0], num_classes)
 
-        x_values = resample_features.values[:, :].reshape(
-            resample_features.shape[0], resample_features.shape[1]
-        )
+        if shape is None:
+            shape = resample_features.shape
+
+        x_values = resample_features.values[:, :].reshape(shape)
 
         SAMPLES = x_values.shape[0]
         # Calculate the indices of each section.
